# frozen_string_literal: true

module Api
  module V1
    # API para sitios
    class SitesController < BaseController
      http_basic_authenticate_with name: ENV['HTTP_BASIC_USER'],
                                   password: ENV['HTTP_BASIC_PASSWORD']

      # Lista de nombres de dominios a emitir certificados
      def index
        render json: Deploy.all.pluck(:hostname)
      end

      # Sitios con hidden service de Tor
      #
      # @return [Array] lista de nombres de sitios sin onion aun
      def hidden_services
        render json: DeployHiddenService.temporary.includes(:site).pluck(:name)
      end

      # Tor va a enviar el onion junto con el nombre del sitio y tenemos
      # que guardarlo en su deploy_hidden_service.
      #
      # @params [String] name
      # @params [String] onion
      def add_onion
        if (site = Site.find_by_name(params[:name]))
          usuarie = GitAuthor.new email: "tor@#{Site.domain}", name: 'Tor'
          service = SiteService.new site: site, usuarie: usuarie,
                                    params: params
          service.add_onion
        end

        head :ok
      end
    end
  end
end
