# frozen_string_literal: true

# Permite generar el sitio en una versión privada, mostrando información
# que no se vería públicamente (borradores, campos privados, etc.)
#
# XXX: La plantilla tiene que soportar esto con el plugin
# jekyll-private-data
class DeployPrivate < DeployLocal
  # No es necesario volver a instalar dependencias
  def deploy
    jekyll_build
  end

  # La URL del sitio dentro del panel.
  #
  # @return [String]
  def url
    Rails.application.routes.url_for(controller: :private, action: :show, site_id: site)
  end

  # Hacer el deploy a un directorio privado.
  #
  # @return [String]
  def destination
    File.join(Rails.root, '_private', site.name)
  end

  # El hostname no se usa para nada, porque el sitio es solo accesible a
  # través del panel de Sutty.
  #
  # @return [String]
  def default_hostname
    "#{site.name}.private.#{Site.domain}"
  end

  # No usar recursos en compresión y habilitar los datos privados
  #
  # @return [Hash]
  def env
    @env ||= super.merge({
                           'JEKYLL_ENV' => 'development',
                           'JEKYLL_PRIVATE' => site.private_key
                         })
  end
end
